@@ -6,6 +6,7 @@ from js.bootstrap import bootstrap_js
 from js.chosen import chosen_jquery
 from js.deform import deform_js
 from js.deform import resource_mapping
+from js.jqueryui import bootstrap as ui_bootstrap_theme
 from pkg_resources import resource_filename
 
 
@@ -22,5 +23,7 @@ deform_bootstrap_js = Resource(
 
 
 def includeme(config):
+    resource_mapping['deform'] = deform_bootstrap_js
     resource_mapping['chosen'] = chosen_jquery
     resource_mapping['bootstrap'] = bootstrap_js
+    resource_mapping['jqueryui'].append(ui_bootstrap_theme)
